@@ -130,7 +130,9 @@ class TokenAuthHttpDownloader(HttpDownloader):
                  more information.
         """
         await asyncio.sleep(0.75)
-        async with self.session.get(self.url, headers=headers, proxy=self.proxy) as response:
+        async with self.session.get(
+            self.url, headers=headers, proxy=self.proxy, proxy_auth=self.proxy_auth, auth=self.auth
+        ) as response:
             self.raise_for_status(response)
             to_return = await self._handle_response(response)
             await response.release()
@@ -159,7 +161,12 @@ class TokenAuthHttpDownloader(HttpDownloader):
             }
             url = self.ansible_auth_url
             async with self.session.post(
-                url, data=form_payload, proxy=self.proxy, raise_for_status=True
+                url,
+                data=form_payload,
+                proxy=self.proxy,
+                proxy_auth=self.proxy_auth,
+                auth=self.auth,
+                raise_for_status=True,
             ) as response:
                 token_data = await response.text()
 
@@ -208,6 +215,10 @@ class AnsibleDownloaderFactory(DownloaderFactory):
         options = {"session": self._session}
         if self._remote.proxy_url:
             options["proxy"] = self._remote.proxy_url
+            if self._remote.proxy_username and self._remote.proxy_password:
+                options["proxy_auth"] = BasicAuth(
+                    login=self._remote.proxy_username, password=self._remote.proxy_password
+                )
 
         if not self._remote.token and self._remote.username and self._remote.password:
             options["auth"] = BasicAuth(login=self._remote.username, password=self._remote.password)
